==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/securityhub/kotlin/inputs/InsightFiltersNetworkDestinationIpv4Args.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.securityhub.kotlin.inputs

import com.pulumi.aws.securityhub.inputs.InsightFiltersNetworkDestinationIpv4Args.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property cidr A finding's CIDR value.
 */
public data class InsightFiltersNetworkDestinationIpv4Args(
    public val cidr: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.securityhub.inputs.InsightFiltersNetworkDestinationIpv4Args> {
    override fun toJava(): com.pulumi.aws.securityhub.inputs.InsightFiltersNetworkDestinationIpv4Args =
        com.pulumi.aws.securityhub.inputs.InsightFiltersNetworkDestinationIpv4Args.builder()
            .cidr(cidr.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InsightFiltersNetworkDestinationIpv4Args].
 */
@PulumiTagMarker
public class InsightFiltersNetworkDestinationIpv4ArgsBuilder internal constructor() {
    private var cidr: Output<String>? = null

    /**
     * @param value A finding's CIDR value.
     */
    @JvmName("vlswhnvxwibyaaxo")
    public suspend fun cidr(`value`: Output<String>) {
        this.cidr = value
    }

    /**
     * @param value A finding's CIDR value.
     */
    @JvmName("airsifhsoacdggua")
    public suspend fun cidr(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.cidr = mapped
    }

    internal fun build(): InsightFiltersNetworkDestinationIpv4Args =
        InsightFiltersNetworkDestinationIpv4Args(
            cidr = cidr ?: throw PulumiNullFieldException("cidr"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/securityhub/kotlin/inputs/InsightFiltersNetworkDestinationIpv4Args.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.securityhub.kotlin.inputs

import com.pulumi.aws.securityhub.inputs.InsightFiltersNetworkDestinationIpv4Args.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property cidr A finding's CIDR value.
 */
public data class InsightFiltersNetworkDestinationIpv4Args(
    public val cidr: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.securityhub.inputs.InsightFiltersNetworkDestinationIpv4Args> {
    override fun toJava(): com.pulumi.aws.securityhub.inputs.InsightFiltersNetworkDestinationIpv4Args = com.pulumi.aws.securityhub.inputs.InsightFiltersNetworkDestinationIpv4Args.builder()
        .cidr(cidr.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InsightFiltersNetworkDestinationIpv4Args].
 */
@PulumiTagMarker
public class InsightFiltersNetworkDestinationIpv4ArgsBuilder internal constructor() {
    private var cidr: Output<String>? = null

    /**
     * @param value A finding's CIDR value.
     */
    @JvmName("leyipfxdfmwwojxu")
    public suspend fun cidr(`value`: Output<String>) {
        this.cidr = value
    }

    /**
     * @param value A finding's CIDR value.
     */
    @JvmName("hcyxuwvnpldognaf")
    public suspend fun cidr(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.cidr = mapped
    }

    internal fun build(): InsightFiltersNetworkDestinationIpv4Args =
        InsightFiltersNetworkDestinationIpv4Args(
            cidr = cidr ?: throw PulumiNullFieldException("cidr"),
        )
}
